==> haskell-non-negative-0.1.2-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-LXEOH02OxOz7WW4EIJtats
key:                  non-negative-0.1.2-LXEOH02OxOz7WW4EIJtats
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  fc948f4f38245195b27a1e2b73914cef
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.0.2/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-LXEOH02OxOz7WW4EIJtats
depends:
    QuickCheck-2.14.2-5toH1Vv8ZxxIieqfaLz1c3 base-4.15.1.0
    utility-ht-0.0.16-CtxbDdOhq8G2cYpheKQAA9

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 non-negative
version:              0.1.2
visibility:           public
id:                   non-negative-0.1.2-ciX9WwjTGuFdmgCDXZ2EO
key:                  non-negative-0.1.2-ciX9WwjTGuFdmgCDXZ2EO
license:              LicenseRef-GPL
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://code.haskell.org/~thielema/non-negative/
synopsis:             Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.

category:             Math
abi:                  6c2654ae64b38b0a54aa75371e8c5f38
exposed:              True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper

hidden-modules:       Numeric.NonNegative.ChunkyPrivate
import-dirs:          /usr/lib/ghc-9.0.2/site-local/non-negative-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-non-negative
hs-libraries:         HSnon-negative-0.1.2-ciX9WwjTGuFdmgCDXZ2EO
depends:
    QuickCheck-2.14.2-6E1s0nkrQNJIUaQam68i9u base-4.15.1.0
    utility-ht-0.0.16-G734DEC6fN4Iw4PEqSNFCi

haddock-interfaces:
    /usr/share/doc/haskell-non-negative/html/non-negative.haddock

haddock-html:         /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
